SpecialDict class — pyDHTMLParser 2.0.8 documentation

### Navigation

- index
- modules |
- previous |
- pyDHTMLParser 2.0.8 documentation »

# SpecialDict class

class `dhtmlparser.specialdict.` `SpecialDict`(*args, **kwds)

  Bases: `collections.OrderedDict`

  This dictionary stores items case sensitive, but compare them case INsensitive.

  Initialize an ordered dictionary. The signature is the same as regular dictionaries, but keyword arguments are not recommended because their insertion order is arbitrary.

### Navigation

- index
- modules |
- previous |
- pyDHTMLParser 2.0.8 documentation »